;************************************ cuenta_display.asm *************************************
;
; Este programa comprueba el funcionamiento del Timer 0 como contador de los impulsos
; aplicados a la lnea RA4/T0CKI, donde se ha conectado un pulsador. Cada vez que presiona
; el pulsador se incrementa el contenido del TMR0 y la cuenta se visualiza en el display 7 segmentos
;
; Como es un incremento por cada impulso aplicado al pin TOCKI no es necesario asignarle
; divisor de frecuencia al TMR0, por tanto, el Prescaler se asigna al Watchdog.
;
; ZONA DE DATOS **********************************************************************

	__CONFIG   _CP_OFF &  _WDT_OFF & _PWRTE_OFF & _XT_OSC
	LIST	   P=16F877A
	INCLUDE  <P16F877A.INC>

	
; ZONA DE CDIGOS ********************************************************************

	ORG 	0
Inicio
	
	bsf	STATUS,RP0		; Acceso al Banco 1.
	bcf STATUS, RP1
	movlw	b'00111000'		; TMR0 como contador por flanco descendente 
	movwf	OPTION_REG		; RA4/T0CKI. Prescaler asignado al Watchdog.
	clrf TRISD				;configura todos los bits de PORTD como salidas
	bcf PORTA,0				;configura RA0 como salida
	bcf	STATUS,RP0		; Acceso al Banco 0.
	clrf TMR0			; Inicializa el contador.
	clrf PORTD			; Inicializa PORTD 
	bsf PORTA,0			;activa el display 7seg DIS0

; La seccin "Principal" es de mantenimiento. Slo se dedica a visualizar el Timer 0.

Principal
	movf	TMR0,W			; Lee el Timer 0.
	call Tabla
	movwf	PORTD
	goto	Principal


;**********************************************************************************
;Tabla: Esta rutina convierte el cdigo binario presente en los 4 bits de menos peso
;del reg. W en su equivalente a 7 segmentos. El cdigo 7 segmentos retorna tambin
;en el reg. W

Tabla:	addwf	PCL,F		;Desplazamiento sobre la tabla
		retlw	b'00111111'	;Dgito 0
		retlw	b'00000110'	;Dgito 1
		retlw	b'01011011'	;Dgito 2
		retlw	b'01001111'	;Dgito 3
		retlw	b'01100110'	;Dgito 4
		retlw	b'01101101'	;Dgito 5
		retlw	b'01111101'	;Dgito 6
		retlw	b'00000111'	;Dgito 7
		retlw	b'01111111'	;Dgito 8
		retlw	b'01100111'	;Dgito 9

	END
	
